from LatexTemplater.TemplateFilter import TemplateFilter
from typing import Dict, Callable


def registrationInfo() -> Dict[str, Callable[[any], str]]:
    """
    Returns all of the infromation needed for registration of filters
    in this file
    """
    return {
        InlineFilter.name: InlineFilter.filter,
    }


class InlineFilter(TemplateFilter):
    """
    Filters a float value
    """

    name = "inline-Eq"

    @staticmethod
    def filter(equation: str) -> str:
        return f"${equation}$"



import argparse
from LatexTemplater import ArgParser
from LatexTemplater.TemplatePluginManager import load_plugins

# include the default plugins
load_plugins(["LatexTemplater.CoreFilters"])


if __name__ == '__main__':
    ArgParser.main()



from LatexTemplater.TemplateFilter import TemplateFilter
from typing import Dict, Callable


def registrationInfo() -> Dict[str, Callable[[any], str]]:
    """
    Returns all of the infromation needed for registration of filters
    in this file
    """
    return {
        DecimalFilter.name: DecimalFilter.filter,
    }


class DecimalFilter(TemplateFilter):
    """
    Filters a float value
    """
    roundTo = 3
    name = "decimal"

    @staticmethod
    def filter(val: float) -> str:
        return str(round(float(val), DecimalFilter.roundTo))



from LatexTemplater.TemplateFilter import TemplateFilter
import os
from typing import Dict, Callable


def registrationInfo() -> Dict[str, Callable[[any], str]]:
    """
    Returns all of the infromation needed for registration of filters
    in this file
    """
    return {
        EquationFilter.name: EquationFilter.filter,
    }


class EquationFilter(TemplateFilter):
    """
    Filters a float value
    """

    name = "eq"

    @staticmethod
    def filter(equation: str) -> str:
        return (r"\begin{equation}" + os.linesep +
                str(equation) + os.linesep +
                r"\end{equation}" + os.linesep)
